API Version: 6.0
Library Version: 2.44.1
enum WebKit.SaveMode
Enum values to specify the different ways in which a WebKitWebView can save its current web page into a self-contained file.
WebKitWebView
WEBKIT_SAVE_MODE_MHTML
Save the current page using the MHTML format.
Content