API Version: 6.0
Library Version: 2.44.1
enum WebKit.UserScriptInjectionTime
Specifies at which place of documents an user script will be inserted.
WEBKIT_USER_SCRIPT_INJECT_AT_DOCUMENT_START
Insert the code of the user script at the beginning of loaded documents. This is the default.
WEBKIT_USER_SCRIPT_INJECT_AT_DOCUMENT_END
Insert the code of the user script at the end of the loaded documents.
Content